import request from '@/plugin/axios'
// 权限树
export function getRightsOption (data) {
  return request({
    url: '/tree/getFacePassageTrees',
    method: 'post',
    data
  })
}
// 人员授权员工树
export function orgPersonTree (data) {
  return request({
    url: '/tree/getFaceUsersTrees',
    method: 'post',
    data
  })
}
export function getUserRightsList (data) {
  return request({
    url: '/face/getFacePassageUserByPage',
    method: 'post',
    data
  })
}
// 回显
export function giveRightsById (data) {
  return request({
    url: '/face/getFacePassageUserById',
    method: 'post',
    data
  })
}
// 授权
export function giveRightsSave (data) {
  return request({
    url: '/face/saveOrUpdataFacePassageUser',
    method: 'post',
    data
  })
}
// 撤销
export function deleteRights (data) {
  return request({
    url: '/face/delFacePassageUserById',
    method: 'post',
    data
  })
}
